Class: Aws::Budgets::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Budgets::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-budgets/client.rb,
sig/client.rbs
Overview
An API client for Budgets. To construct a client, you need to configure a :region and :credentials.
client = Aws::Budgets::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateBudgetActionResponseSuccess, _CreateBudgetResponseSuccess, _CreateNotificationResponseSuccess, _CreateSubscriberResponseSuccess, _DeleteBudgetActionResponseSuccess, _DeleteBudgetResponseSuccess, _DeleteNotificationResponseSuccess, _DeleteSubscriberResponseSuccess, _DescribeBudgetActionHistoriesResponseSuccess, _DescribeBudgetActionResponseSuccess, _DescribeBudgetActionsForAccountResponseSuccess, _DescribeBudgetActionsForBudgetResponseSuccess, _DescribeBudgetNotificationsForAccountResponseSuccess, _DescribeBudgetPerformanceHistoryResponseSuccess, _DescribeBudgetResponseSuccess, _DescribeBudgetsResponseSuccess, _DescribeNotificationsForBudgetResponseSuccess, _DescribeSubscribersForNotificationResponseSuccess, _ExecuteBudgetActionResponseSuccess, _ListTagsForResourceResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateBudgetActionResponseSuccess, _UpdateBudgetResponseSuccess, _UpdateNotificationResponseSuccess, _UpdateSubscriberResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_budget(params = {}) ⇒ Struct
Creates a budget and, if included, notifications and subscribers.
-
#create_budget_action(params = {}) ⇒ Types::CreateBudgetActionResponse
Creates a budget action.
-
#create_notification(params = {}) ⇒ Struct
Creates a notification.
-
#create_subscriber(params = {}) ⇒ Struct
Creates a subscriber.
-
#delete_budget(params = {}) ⇒ Struct
Deletes a budget.
-
#delete_budget_action(params = {}) ⇒ Types::DeleteBudgetActionResponse
Deletes a budget action.
-
#delete_notification(params = {}) ⇒ Struct
Deletes a notification.
-
#delete_subscriber(params = {}) ⇒ Struct
Deletes a subscriber.
-
#describe_budget(params = {}) ⇒ Types::DescribeBudgetResponse
Describes a budget.
-
#describe_budget_action(params = {}) ⇒ Types::DescribeBudgetActionResponse
Describes a budget action detail.
-
#describe_budget_action_histories(params = {}) ⇒ Types::DescribeBudgetActionHistoriesResponse
Describes a budget action history detail.
-
#describe_budget_actions_for_account(params = {}) ⇒ Types::DescribeBudgetActionsForAccountResponse
Describes all of the budget actions for an account.
-
#describe_budget_actions_for_budget(params = {}) ⇒ Types::DescribeBudgetActionsForBudgetResponse
Describes all of the budget actions for a budget.
-
#describe_budget_notifications_for_account(params = {}) ⇒ Types::DescribeBudgetNotificationsForAccountResponse
Lists the budget names and notifications that are associated with an account.
-
#describe_budget_performance_history(params = {}) ⇒ Types::DescribeBudgetPerformanceHistoryResponse
Describes the history for
DAILY,MONTHLY, andQUARTERLYbudgets. -
#describe_budgets(params = {}) ⇒ Types::DescribeBudgetsResponse
Lists the budgets that are associated with an account.
-
#describe_notifications_for_budget(params = {}) ⇒ Types::DescribeNotificationsForBudgetResponse
Lists the notifications that are associated with a budget.
-
#describe_subscribers_for_notification(params = {}) ⇒ Types::DescribeSubscribersForNotificationResponse
Lists the subscribers that are associated with a notification.
-
#execute_budget_action(params = {}) ⇒ Types::ExecuteBudgetActionResponse
Executes a budget action.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists tags associated with a budget or budget action resource.
-
#tag_resource(params = {}) ⇒ Struct
Creates tags for a budget or budget action resource.
-
#untag_resource(params = {}) ⇒ Struct
Deletes tags associated with a budget or budget action resource.
-
#update_budget(params = {}) ⇒ Struct
Updates a budget.
-
#update_budget_action(params = {}) ⇒ Types::UpdateBudgetActionResponse
Updates a budget action.
-
#update_notification(params = {}) ⇒ Struct
Updates a notification.
-
#update_subscriber(params = {}) ⇒ Struct
Updates a subscriber.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-budgets/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2337 2338 2339 |
# File 'lib/aws-sdk-budgets/client.rb', line 2337 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2340 2341 2342 |
# File 'lib/aws-sdk-budgets/client.rb', line 2340 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2310 2311 2312 2313 2314 2315 2316 2317 2318 2319 2320 2321 2322 2323 2324 2325 2326 |
# File 'lib/aws-sdk-budgets/client.rb', line 2310 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Budgets') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-budgets' context[:gem_version] = '1.111.0' Seahorse::Client::Request.new(handlers, context) end |
#create_budget(params = {}) ⇒ Struct
Creates a budget and, if included, notifications and subscribers.
Only one of BudgetLimit or PlannedBudgetLimits can be present in
the syntax at one time. Use the syntax that matches your use case. The
Request Syntax section shows the BudgetLimit syntax. For
PlannedBudgetLimits, see the Examples section.
Similarly, only one set of filter and metric selections can be
present
in the syntax at one time. Either FilterExpression and Metrics or
CostFilters and CostTypes, not both or a different combination. We
recommend using FilterExpression and Metrics as they provide more
flexible and powerful filtering capabilities. The Request Syntax
section shows the FilterExpression/Metrics syntax.
86 |
# File 'sig/client.rbs', line 86
def create_budget: (
|
#create_budget_action(params = {}) ⇒ Types::CreateBudgetActionResponse
Creates a budget action.
122 |
# File 'sig/client.rbs', line 122
def create_budget_action: (
|
#create_notification(params = {}) ⇒ Struct
Creates a notification. You must create the budget before you create the associated notification.
153 |
# File 'sig/client.rbs', line 153
def create_notification: (
|
#create_subscriber(params = {}) ⇒ Struct
Creates a subscriber. You must create the associated budget and notification before you create the subscriber.
176 |
# File 'sig/client.rbs', line 176
def create_subscriber: (
|
#delete_budget(params = {}) ⇒ Struct
Deletes a budget. You can delete your budget at any time.
Deleting a budget also deletes the notifications and subscribers that are associated with that budget.
197 |
# File 'sig/client.rbs', line 197
def delete_budget: (
|
#delete_budget_action(params = {}) ⇒ Types::DeleteBudgetActionResponse
Deletes a budget action.
210 |
# File 'sig/client.rbs', line 210
def delete_budget_action: (
|
#delete_notification(params = {}) ⇒ Struct
Deletes a notification.
Deleting a notification also deletes the subscribers that are associated with the notification.
221 |
# File 'sig/client.rbs', line 221
def delete_notification: (
|
#delete_subscriber(params = {}) ⇒ Struct
Deletes a subscriber.
Deleting the last subscriber to a notification also deletes the notification.
238 |
# File 'sig/client.rbs', line 238
def delete_subscriber: (
|
#describe_budget(params = {}) ⇒ Types::DescribeBudgetResponse
Describes a budget.
The Request Syntax section shows the BudgetLimit syntax. For
PlannedBudgetLimits, see the Examples section.
260 |
# File 'sig/client.rbs', line 260
def describe_budget: (
|
#describe_budget_action(params = {}) ⇒ Types::DescribeBudgetActionResponse
Describes a budget action detail.
274 |
# File 'sig/client.rbs', line 274
def describe_budget_action: (
|
#describe_budget_action_histories(params = {}) ⇒ Types::DescribeBudgetActionHistoriesResponse
Describes a budget action history detail.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
287 |
# File 'sig/client.rbs', line 287
def describe_budget_action_histories: (
|
#describe_budget_actions_for_account(params = {}) ⇒ Types::DescribeBudgetActionsForAccountResponse
Describes all of the budget actions for an account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
306 |
# File 'sig/client.rbs', line 306
def describe_budget_actions_for_account: (
|
#describe_budget_actions_for_budget(params = {}) ⇒ Types::DescribeBudgetActionsForBudgetResponse
Describes all of the budget actions for a budget.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
319 |
# File 'sig/client.rbs', line 319
def describe_budget_actions_for_budget: (
|
#describe_budget_notifications_for_account(params = {}) ⇒ Types::DescribeBudgetNotificationsForAccountResponse
Lists the budget names and notifications that are associated with an account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
333 |
# File 'sig/client.rbs', line 333
def describe_budget_notifications_for_account: (
|
#describe_budget_performance_history(params = {}) ⇒ Types::DescribeBudgetPerformanceHistoryResponse
Describes the history for DAILY, MONTHLY, and QUARTERLY budgets.
Budget history isn't available for ANNUAL budgets.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
346 |
# File 'sig/client.rbs', line 346
def describe_budget_performance_history: (
|
#describe_budgets(params = {}) ⇒ Types::DescribeBudgetsResponse
Lists the budgets that are associated with an account.
The Request Syntax section shows the BudgetLimit syntax. For
PlannedBudgetLimits, see the Examples section.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
364 |
# File 'sig/client.rbs', line 364
def describe_budgets: (
|
#describe_notifications_for_budget(params = {}) ⇒ Types::DescribeNotificationsForBudgetResponse
Lists the notifications that are associated with a budget.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
378 |
# File 'sig/client.rbs', line 378
def describe_notifications_for_budget: (
|
#describe_subscribers_for_notification(params = {}) ⇒ Types::DescribeSubscribersForNotificationResponse
Lists the subscribers that are associated with a notification.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
392 |
# File 'sig/client.rbs', line 392
def describe_subscribers_for_notification: (
|
#execute_budget_action(params = {}) ⇒ Types::ExecuteBudgetActionResponse
Executes a budget action.
415 |
# File 'sig/client.rbs', line 415
def execute_budget_action: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists tags associated with a budget or budget action resource.
428 |
# File 'sig/client.rbs', line 428
def list_tags_for_resource: (
|
#tag_resource(params = {}) ⇒ Struct
Creates tags for a budget or budget action resource.
437 |
# File 'sig/client.rbs', line 437
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Deletes tags associated with a budget or budget action resource.
452 |
# File 'sig/client.rbs', line 452
def untag_resource: (
|
#update_budget(params = {}) ⇒ Struct
Updates a budget. You can change every part of a budget except for the
budgetName and the calculatedSpend. When you modify a budget, the
calculatedSpend drops to zero until Amazon Web Services has new
usage data to use for forecasting.
Only one of BudgetLimit or PlannedBudgetLimits can be present in
the syntax at one time. Use the syntax that matches your case. The
Request Syntax section shows the BudgetLimit syntax. For
PlannedBudgetLimits, see the Examples section.
Similarly, only one set of filter and metric selections can be
present
in the syntax at one time. Either FilterExpression and Metrics or
CostFilters and CostTypes, not both or a different combination. We
recommend using FilterExpression and Metrics as they provide more
flexible and powerful filtering capabilities. The Request Syntax
section shows the FilterExpression/Metrics syntax.
462 |
# File 'sig/client.rbs', line 462
def update_budget: (
|
#update_budget_action(params = {}) ⇒ Types::UpdateBudgetActionResponse
Updates a budget action.
476 |
# File 'sig/client.rbs', line 476
def update_budget_action: (
|
#update_notification(params = {}) ⇒ Struct
Updates a notification.
501 |
# File 'sig/client.rbs', line 501
def update_notification: (
|
#update_subscriber(params = {}) ⇒ Struct
Updates a subscriber.
525 |
# File 'sig/client.rbs', line 525
def update_subscriber: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2330 2331 2332 |
# File 'lib/aws-sdk-budgets/client.rb', line 2330 def waiter_names [] end |