Class: Aws::Budgets::Types::BudgetNotificationsForAccount

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-budgets/types.rb

Overview

The budget name and associated notifications for an account.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#budget_nameString

A string that represents the budget name. The “:” and “\” characters, and the “/action/” substring, aren’t allowed.

Budget names are validated for content. Names that contain phone numbers, URLs, or email addresses combined with certain terms may be rejected.

Returns:

  • (String)


390
391
392
393
394
395
# File 'lib/aws-sdk-budgets/types.rb', line 390

class BudgetNotificationsForAccount < Struct.new(
  :notifications,
  :budget_name)
  SENSITIVE = []
  include Aws::Structure
end

#notificationsArray<Types::Notification>

A list of notifications.

Returns:



390
391
392
393
394
395
# File 'lib/aws-sdk-budgets/types.rb', line 390

class BudgetNotificationsForAccount < Struct.new(
  :notifications,
  :budget_name)
  SENSITIVE = []
  include Aws::Structure
end