Class: Aws::Budgets::Types::BudgetPerformanceHistory

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-budgets/types.rb

Overview

A history of the state of a budget at the end of the budget's specified time period.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#billing_view_arnString

The Amazon Resource Name (ARN) that uniquely identifies a specific billing view. The ARN is used to specify which particular billing view you want to interact with or retrieve information from when making API calls related to Amazon Web Services Billing and Cost Management features. The BillingViewArn can be retrieved by calling the ListBillingViews API.

Returns:

  • (String)


453
454
455
456
457
458
459
460
461
462
463
464
465
# File 'lib/aws-sdk-budgets/types.rb', line 453

class BudgetPerformanceHistory < Struct.new(
  :budget_name,
  :budget_type,
  :cost_filters,
  :cost_types,
  :time_unit,
  :billing_view_arn,
  :budgeted_and_actual_amounts_list,
  :filter_expression,
  :metrics)
  SENSITIVE = []
  include Aws::Structure
end

#budget_nameString

A string that represents the budget name. The ":" and "\" characters, and the "/action/" substring, aren't allowed.

Budget names are validated for content. Names that contain phone numbers, URLs, or email addresses combined with certain terms may be rejected.

Returns:

  • (String)


453
454
455
456
457
458
459
460
461
462
463
464
465
# File 'lib/aws-sdk-budgets/types.rb', line 453

class BudgetPerformanceHistory < Struct.new(
  :budget_name,
  :budget_type,
  :cost_filters,
  :cost_types,
  :time_unit,
  :billing_view_arn,
  :budgeted_and_actual_amounts_list,
  :filter_expression,
  :metrics)
  SENSITIVE = []
  include Aws::Structure
end

#budget_typeString

The type of a budget. It must be one of the following types:

COST, USAGE, RI_UTILIZATION, RI_COVERAGE, SAVINGS_PLANS_UTILIZATION, or SAVINGS_PLANS_COVERAGE.

Returns:

  • (String)


453
454
455
456
457
458
459
460
461
462
463
464
465
# File 'lib/aws-sdk-budgets/types.rb', line 453

class BudgetPerformanceHistory < Struct.new(
  :budget_name,
  :budget_type,
  :cost_filters,
  :cost_types,
  :time_unit,
  :billing_view_arn,
  :budgeted_and_actual_amounts_list,
  :filter_expression,
  :metrics)
  SENSITIVE = []
  include Aws::Structure
end

#budgeted_and_actual_amounts_listArray<Types::BudgetedAndActualAmounts>

A list of amounts of cost or usage that you created budgets for, which are compared to your actual costs or usage.



453
454
455
456
457
458
459
460
461
462
463
464
465
# File 'lib/aws-sdk-budgets/types.rb', line 453

class BudgetPerformanceHistory < Struct.new(
  :budget_name,
  :budget_type,
  :cost_filters,
  :cost_types,
  :time_unit,
  :billing_view_arn,
  :budgeted_and_actual_amounts_list,
  :filter_expression,
  :metrics)
  SENSITIVE = []
  include Aws::Structure
end

#cost_filtersHash<String,Array<String>>

The history of the cost filters for a budget during the specified time period.

Returns:

  • (Hash<String,Array<String>>)


453
454
455
456
457
458
459
460
461
462
463
464
465
# File 'lib/aws-sdk-budgets/types.rb', line 453

class BudgetPerformanceHistory < Struct.new(
  :budget_name,
  :budget_type,
  :cost_filters,
  :cost_types,
  :time_unit,
  :billing_view_arn,
  :budgeted_and_actual_amounts_list,
  :filter_expression,
  :metrics)
  SENSITIVE = []
  include Aws::Structure
end

#cost_typesTypes::CostTypes

The history of the cost types for a budget during the specified time period.

Returns:



453
454
455
456
457
458
459
460
461
462
463
464
465
# File 'lib/aws-sdk-budgets/types.rb', line 453

class BudgetPerformanceHistory < Struct.new(
  :budget_name,
  :budget_type,
  :cost_filters,
  :cost_types,
  :time_unit,
  :billing_view_arn,
  :budgeted_and_actual_amounts_list,
  :filter_expression,
  :metrics)
  SENSITIVE = []
  include Aws::Structure
end

#filter_expressionTypes::Expression

The filtering dimensions for the budget and their corresponding values.

Returns:



453
454
455
456
457
458
459
460
461
462
463
464
465
# File 'lib/aws-sdk-budgets/types.rb', line 453

class BudgetPerformanceHistory < Struct.new(
  :budget_name,
  :budget_type,
  :cost_filters,
  :cost_types,
  :time_unit,
  :billing_view_arn,
  :budgeted_and_actual_amounts_list,
  :filter_expression,
  :metrics)
  SENSITIVE = []
  include Aws::Structure
end

#metricsArray<String>

The definition for how the budget data is aggregated.

Returns:

  • (Array<String>)


453
454
455
456
457
458
459
460
461
462
463
464
465
# File 'lib/aws-sdk-budgets/types.rb', line 453

class BudgetPerformanceHistory < Struct.new(
  :budget_name,
  :budget_type,
  :cost_filters,
  :cost_types,
  :time_unit,
  :billing_view_arn,
  :budgeted_and_actual_amounts_list,
  :filter_expression,
  :metrics)
  SENSITIVE = []
  include Aws::Structure
end

#time_unitString

The time unit of the budget, such as MONTHLY or QUARTERLY.

Returns:

  • (String)


453
454
455
456
457
458
459
460
461
462
463
464
465
# File 'lib/aws-sdk-budgets/types.rb', line 453

class BudgetPerformanceHistory < Struct.new(
  :budget_name,
  :budget_type,
  :cost_filters,
  :cost_types,
  :time_unit,
  :billing_view_arn,
  :budgeted_and_actual_amounts_list,
  :filter_expression,
  :metrics)
  SENSITIVE = []
  include Aws::Structure
end