Class: Aws::Budgets::Types::DescribeBudgetActionHistoriesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-budgets/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_idString

The account ID of the user. It’s a 12-digit number.

Returns:

  • (String)


1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
# File 'lib/aws-sdk-budgets/types.rb', line 1024

class DescribeBudgetActionHistoriesRequest < Struct.new(
  :account_id,
  :budget_name,
  :action_id,
  :time_period,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#action_idString

A system-generated universally unique identifier (UUID) for the action.

Returns:

  • (String)


1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
# File 'lib/aws-sdk-budgets/types.rb', line 1024

class DescribeBudgetActionHistoriesRequest < Struct.new(
  :account_id,
  :budget_name,
  :action_id,
  :time_period,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#budget_nameString

A string that represents the budget name. The “:” and “\” characters, and the “/action/” substring, aren’t allowed.

Budget names are validated for content. Names that contain phone numbers, URLs, or email addresses combined with certain terms may be rejected.

Returns:

  • (String)


1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
# File 'lib/aws-sdk-budgets/types.rb', line 1024

class DescribeBudgetActionHistoriesRequest < Struct.new(
  :account_id,
  :budget_name,
  :action_id,
  :time_period,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

An integer that represents how many entries a paginated response contains. The maximum is 100.

Returns:

  • (Integer)


1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
# File 'lib/aws-sdk-budgets/types.rb', line 1024

class DescribeBudgetActionHistoriesRequest < Struct.new(
  :account_id,
  :budget_name,
  :action_id,
  :time_period,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A generic string.

Returns:

  • (String)


1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
# File 'lib/aws-sdk-budgets/types.rb', line 1024

class DescribeBudgetActionHistoriesRequest < Struct.new(
  :account_id,
  :budget_name,
  :action_id,
  :time_period,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#time_periodTypes::TimePeriod

The period of time that’s covered by a budget. The period has a start date and an end date. The start date must come before the end date. There are no restrictions on the end date.

Returns:



1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
# File 'lib/aws-sdk-budgets/types.rb', line 1024

class DescribeBudgetActionHistoriesRequest < Struct.new(
  :account_id,
  :budget_name,
  :action_id,
  :time_period,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end