Class: Aws::Budgets::Types::DescribeBudgetPerformanceHistoryResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-budgets/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#budget_performance_historyTypes::BudgetPerformanceHistory

The history of how often the budget has gone into an ALARM state.

For DAILY budgets, the history saves the state of the budget for the last 60 days. For MONTHLY budgets, the history saves the state of the budget for the current month plus the last 12 months. For QUARTERLY budgets, the history saves the state of the budget for the last four quarters.



1270
1271
1272
1273
1274
1275
# File 'lib/aws-sdk-budgets/types.rb', line 1270

class DescribeBudgetPerformanceHistoryResponse < Struct.new(
  :budget_performance_history,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A generic string.

Returns:

  • (String)


1270
1271
1272
1273
1274
1275
# File 'lib/aws-sdk-budgets/types.rb', line 1270

class DescribeBudgetPerformanceHistoryResponse < Struct.new(
  :budget_performance_history,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end