Class: Aws::Budgets::Types::DescribeBudgetRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Budgets::Types::DescribeBudgetRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-budgets/types.rb
Overview
Request of DescribeBudget
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_id ⇒ String
The ‘accountId` that is associated with the budget that you want a description of.
-
#budget_name ⇒ String
The name of the budget that you want a description of.
-
#show_filter_expression ⇒ Boolean
Specifies whether the response includes the filter expression associated with the budget.
Instance Attribute Details
#account_id ⇒ String
The ‘accountId` that is associated with the budget that you want a description of.
1295 1296 1297 1298 1299 1300 1301 |
# File 'lib/aws-sdk-budgets/types.rb', line 1295 class DescribeBudgetRequest < Struct.new( :account_id, :budget_name, :show_filter_expression) SENSITIVE = [] include Aws::Structure end |
#budget_name ⇒ String
The name of the budget that you want a description of.
1295 1296 1297 1298 1299 1300 1301 |
# File 'lib/aws-sdk-budgets/types.rb', line 1295 class DescribeBudgetRequest < Struct.new( :account_id, :budget_name, :show_filter_expression) SENSITIVE = [] include Aws::Structure end |
#show_filter_expression ⇒ Boolean
Specifies whether the response includes the filter expression associated with the budget. By showing the filter expression, you can see detailed filtering logic applied to the budget, such as Amazon Web Services services or tags that are being tracked.
1295 1296 1297 1298 1299 1300 1301 |
# File 'lib/aws-sdk-budgets/types.rb', line 1295 class DescribeBudgetRequest < Struct.new( :account_id, :budget_name, :show_filter_expression) SENSITIVE = [] include Aws::Structure end |