Class: Aws::Budgets::Types::DescribeBudgetsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Budgets::Types::DescribeBudgetsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-budgets/types.rb
Overview
Request of DescribeBudgets
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_id ⇒ String
The ‘accountId` that is associated with the budgets that you want to describe.
-
#max_results ⇒ Integer
An integer that represents how many budgets a paginated response contains.
-
#next_token ⇒ String
The pagination token that you include in your request to indicate the next set of results that you want to retrieve.
-
#show_filter_expression ⇒ Boolean
Specifies whether the response includes the filter expression associated with the budgets.
Instance Attribute Details
#account_id ⇒ String
The ‘accountId` that is associated with the budgets that you want to describe.
1339 1340 1341 1342 1343 1344 1345 1346 |
# File 'lib/aws-sdk-budgets/types.rb', line 1339 class DescribeBudgetsRequest < Struct.new( :account_id, :max_results, :next_token, :show_filter_expression) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
An integer that represents how many budgets a paginated response contains. The default is 100.
1339 1340 1341 1342 1343 1344 1345 1346 |
# File 'lib/aws-sdk-budgets/types.rb', line 1339 class DescribeBudgetsRequest < Struct.new( :account_id, :max_results, :next_token, :show_filter_expression) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The pagination token that you include in your request to indicate the next set of results that you want to retrieve.
1339 1340 1341 1342 1343 1344 1345 1346 |
# File 'lib/aws-sdk-budgets/types.rb', line 1339 class DescribeBudgetsRequest < Struct.new( :account_id, :max_results, :next_token, :show_filter_expression) SENSITIVE = [] include Aws::Structure end |
#show_filter_expression ⇒ Boolean
Specifies whether the response includes the filter expression associated with the budgets. By showing the filter expression, you can see detailed filtering logic applied to the budgets, such as Amazon Web Services services or tags that are being tracked.
1339 1340 1341 1342 1343 1344 1345 1346 |
# File 'lib/aws-sdk-budgets/types.rb', line 1339 class DescribeBudgetsRequest < Struct.new( :account_id, :max_results, :next_token, :show_filter_expression) SENSITIVE = [] include Aws::Structure end |