Class: Aws::Budgets::Types::UpdateBudgetActionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Budgets::Types::UpdateBudgetActionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-budgets/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_id ⇒ String
The account ID of the user.
-
#action_id ⇒ String
A system-generated universally unique identifier (UUID) for the action.
-
#action_threshold ⇒ Types::ActionThreshold
The trigger threshold of the action.
-
#approval_model ⇒ String
This specifies if the action needs manual or automatic approval.
-
#budget_name ⇒ String
A string that represents the budget name.
-
#definition ⇒ Types::Definition
Specifies all of the type-specific parameters.
-
#execution_role_arn ⇒ String
The role passed for action execution and reversion.
-
#notification_type ⇒ String
The type of a notification.
-
#subscribers ⇒ Array<Types::Subscriber>
A list of subscribers.
Instance Attribute Details
#account_id ⇒ String
The account ID of the user. It’s a 12-digit number.
2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 |
# File 'lib/aws-sdk-budgets/types.rb', line 2164 class UpdateBudgetActionRequest < Struct.new( :account_id, :budget_name, :action_id, :notification_type, :action_threshold, :definition, :execution_role_arn, :approval_model, :subscribers) SENSITIVE = [] include Aws::Structure end |
#action_id ⇒ String
A system-generated universally unique identifier (UUID) for the action.
2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 |
# File 'lib/aws-sdk-budgets/types.rb', line 2164 class UpdateBudgetActionRequest < Struct.new( :account_id, :budget_name, :action_id, :notification_type, :action_threshold, :definition, :execution_role_arn, :approval_model, :subscribers) SENSITIVE = [] include Aws::Structure end |
#action_threshold ⇒ Types::ActionThreshold
The trigger threshold of the action.
2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 |
# File 'lib/aws-sdk-budgets/types.rb', line 2164 class UpdateBudgetActionRequest < Struct.new( :account_id, :budget_name, :action_id, :notification_type, :action_threshold, :definition, :execution_role_arn, :approval_model, :subscribers) SENSITIVE = [] include Aws::Structure end |
#approval_model ⇒ String
This specifies if the action needs manual or automatic approval.
2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 |
# File 'lib/aws-sdk-budgets/types.rb', line 2164 class UpdateBudgetActionRequest < Struct.new( :account_id, :budget_name, :action_id, :notification_type, :action_threshold, :definition, :execution_role_arn, :approval_model, :subscribers) SENSITIVE = [] include Aws::Structure end |
#budget_name ⇒ String
A string that represents the budget name. The “:” and “\” characters, and the “/action/” substring, aren’t allowed.
Budget names are validated for content. Names that contain phone numbers, URLs, or email addresses combined with certain terms may be rejected.
2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 |
# File 'lib/aws-sdk-budgets/types.rb', line 2164 class UpdateBudgetActionRequest < Struct.new( :account_id, :budget_name, :action_id, :notification_type, :action_threshold, :definition, :execution_role_arn, :approval_model, :subscribers) SENSITIVE = [] include Aws::Structure end |
#definition ⇒ Types::Definition
Specifies all of the type-specific parameters.
2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 |
# File 'lib/aws-sdk-budgets/types.rb', line 2164 class UpdateBudgetActionRequest < Struct.new( :account_id, :budget_name, :action_id, :notification_type, :action_threshold, :definition, :execution_role_arn, :approval_model, :subscribers) SENSITIVE = [] include Aws::Structure end |
#execution_role_arn ⇒ String
The role passed for action execution and reversion. Roles and actions must be in the same account.
2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 |
# File 'lib/aws-sdk-budgets/types.rb', line 2164 class UpdateBudgetActionRequest < Struct.new( :account_id, :budget_name, :action_id, :notification_type, :action_threshold, :definition, :execution_role_arn, :approval_model, :subscribers) SENSITIVE = [] include Aws::Structure end |
#notification_type ⇒ String
The type of a notification. It must be ACTUAL or FORECASTED.
2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 |
# File 'lib/aws-sdk-budgets/types.rb', line 2164 class UpdateBudgetActionRequest < Struct.new( :account_id, :budget_name, :action_id, :notification_type, :action_threshold, :definition, :execution_role_arn, :approval_model, :subscribers) SENSITIVE = [] include Aws::Structure end |
#subscribers ⇒ Array<Types::Subscriber>
A list of subscribers.
2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 |
# File 'lib/aws-sdk-budgets/types.rb', line 2164 class UpdateBudgetActionRequest < Struct.new( :account_id, :budget_name, :action_id, :notification_type, :action_threshold, :definition, :execution_role_arn, :approval_model, :subscribers) SENSITIVE = [] include Aws::Structure end |