Class: Aws::Budgets::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Budgets::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-budgets/client.rb
Overview
An API client for Budgets. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::Budgets::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_budget(params = {}) ⇒ Struct
Creates a budget and, if included, notifications and subscribers.
-
#create_budget_action(params = {}) ⇒ Types::CreateBudgetActionResponse
Creates a budget action.
-
#create_notification(params = {}) ⇒ Struct
Creates a notification.
-
#create_subscriber(params = {}) ⇒ Struct
Creates a subscriber.
-
#delete_budget(params = {}) ⇒ Struct
Deletes a budget.
-
#delete_budget_action(params = {}) ⇒ Types::DeleteBudgetActionResponse
Deletes a budget action.
-
#delete_notification(params = {}) ⇒ Struct
Deletes a notification.
-
#delete_subscriber(params = {}) ⇒ Struct
Deletes a subscriber.
-
#describe_budget(params = {}) ⇒ Types::DescribeBudgetResponse
Describes a budget.
-
#describe_budget_action(params = {}) ⇒ Types::DescribeBudgetActionResponse
Describes a budget action detail.
-
#describe_budget_action_histories(params = {}) ⇒ Types::DescribeBudgetActionHistoriesResponse
Describes a budget action history detail.
-
#describe_budget_actions_for_account(params = {}) ⇒ Types::DescribeBudgetActionsForAccountResponse
Describes all of the budget actions for an account.
-
#describe_budget_actions_for_budget(params = {}) ⇒ Types::DescribeBudgetActionsForBudgetResponse
Describes all of the budget actions for a budget.
-
#describe_budget_notifications_for_account(params = {}) ⇒ Types::DescribeBudgetNotificationsForAccountResponse
Lists the budget names and notifications that are associated with an account.
-
#describe_budget_performance_history(params = {}) ⇒ Types::DescribeBudgetPerformanceHistoryResponse
Describes the history for ‘DAILY`, `MONTHLY`, and `QUARTERLY` budgets.
-
#describe_budgets(params = {}) ⇒ Types::DescribeBudgetsResponse
Lists the budgets that are associated with an account.
-
#describe_notifications_for_budget(params = {}) ⇒ Types::DescribeNotificationsForBudgetResponse
Lists the notifications that are associated with a budget.
-
#describe_subscribers_for_notification(params = {}) ⇒ Types::DescribeSubscribersForNotificationResponse
Lists the subscribers that are associated with a notification.
-
#execute_budget_action(params = {}) ⇒ Types::ExecuteBudgetActionResponse
Executes a budget action.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists tags associated with a budget or budget action resource.
-
#tag_resource(params = {}) ⇒ Struct
Creates tags for a budget or budget action resource.
-
#untag_resource(params = {}) ⇒ Struct
Deletes tags associated with a budget or budget action resource.
-
#update_budget(params = {}) ⇒ Struct
Updates a budget.
-
#update_budget_action(params = {}) ⇒ Types::UpdateBudgetActionResponse
Updates a budget action.
-
#update_notification(params = {}) ⇒ Struct
Updates a notification.
-
#update_subscriber(params = {}) ⇒ Struct
Updates a subscriber.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-budgets/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2337 2338 2339 |
# File 'lib/aws-sdk-budgets/client.rb', line 2337 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2340 2341 2342 |
# File 'lib/aws-sdk-budgets/client.rb', line 2340 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2310 2311 2312 2313 2314 2315 2316 2317 2318 2319 2320 2321 2322 2323 2324 2325 2326 |
# File 'lib/aws-sdk-budgets/client.rb', line 2310 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Budgets') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-budgets' context[:gem_version] = '1.109.0' Seahorse::Client::Request.new(handlers, context) end |
#create_budget(params = {}) ⇒ Struct
Creates a budget and, if included, notifications and subscribers.
Only one of ‘BudgetLimit` or `PlannedBudgetLimits` can be present in the syntax at one time. Use the syntax that matches your use case. The Request Syntax section shows the `BudgetLimit` syntax. For `PlannedBudgetLimits`, see the [Examples] section.
Similarly, only one set of filter and metric selections can be
present in the syntax at one time. Either ‘FilterExpression` and `Metrics` or `CostFilters` and `CostTypes`, not both or a different combination. We recommend using `FilterExpression` and `Metrics` as they provide more flexible and powerful filtering capabilities. The Request Syntax section shows the `FilterExpression`/`Metrics` syntax.
645 646 647 648 |
# File 'lib/aws-sdk-budgets/client.rb', line 645 def create_budget(params = {}, = {}) req = build_request(:create_budget, params) req.send_request() end |
#create_budget_action(params = {}) ⇒ Types::CreateBudgetActionResponse
Creates a budget action.
750 751 752 753 |
# File 'lib/aws-sdk-budgets/client.rb', line 750 def create_budget_action(params = {}, = {}) req = build_request(:create_budget_action, params) req.send_request() end |
#create_notification(params = {}) ⇒ Struct
Creates a notification. You must create the budget before you create the associated notification.
798 799 800 801 |
# File 'lib/aws-sdk-budgets/client.rb', line 798 def create_notification(params = {}, = {}) req = build_request(:create_notification, params) req.send_request() end |
#create_subscriber(params = {}) ⇒ Struct
Creates a subscriber. You must create the associated budget and notification before you create the subscriber.
842 843 844 845 |
# File 'lib/aws-sdk-budgets/client.rb', line 842 def create_subscriber(params = {}, = {}) req = build_request(:create_subscriber, params) req.send_request() end |
#delete_budget(params = {}) ⇒ Struct
Deletes a budget. You can delete your budget at any time.
Deleting a budget also deletes the notifications and subscribers that are associated with that budget.
870 871 872 873 |
# File 'lib/aws-sdk-budgets/client.rb', line 870 def delete_budget(params = {}, = {}) req = build_request(:delete_budget, params) req.send_request() end |
#delete_budget_action(params = {}) ⇒ Types::DeleteBudgetActionResponse
Deletes a budget action.
939 940 941 942 |
# File 'lib/aws-sdk-budgets/client.rb', line 939 def delete_budget_action(params = {}, = {}) req = build_request(:delete_budget_action, params) req.send_request() end |
#delete_notification(params = {}) ⇒ Struct
Deletes a notification.
Deleting a notification also deletes the subscribers that are associated with the notification.
977 978 979 980 |
# File 'lib/aws-sdk-budgets/client.rb', line 977 def delete_notification(params = {}, = {}) req = build_request(:delete_notification, params) req.send_request() end |
#delete_subscriber(params = {}) ⇒ Struct
Deletes a subscriber.
Deleting the last subscriber to a notification also deletes the notification.
1022 1023 1024 1025 |
# File 'lib/aws-sdk-budgets/client.rb', line 1022 def delete_subscriber(params = {}, = {}) req = build_request(:delete_subscriber, params) req.send_request() end |
#describe_budget(params = {}) ⇒ Types::DescribeBudgetResponse
Describes a budget.
The Request Syntax section shows the ‘BudgetLimit` syntax. For `PlannedBudgetLimits`, see the [Examples] section.
1125 1126 1127 1128 |
# File 'lib/aws-sdk-budgets/client.rb', line 1125 def describe_budget(params = {}, = {}) req = build_request(:describe_budget, params) req.send_request() end |
#describe_budget_action(params = {}) ⇒ Types::DescribeBudgetActionResponse
Describes a budget action detail.
1194 1195 1196 1197 |
# File 'lib/aws-sdk-budgets/client.rb', line 1194 def describe_budget_action(params = {}, = {}) req = build_request(:describe_budget_action, params) req.send_request() end |
#describe_budget_action_histories(params = {}) ⇒ Types::DescribeBudgetActionHistoriesResponse
Describes a budget action history detail.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1286 1287 1288 1289 |
# File 'lib/aws-sdk-budgets/client.rb', line 1286 def describe_budget_action_histories(params = {}, = {}) req = build_request(:describe_budget_action_histories, params) req.send_request() end |
#describe_budget_actions_for_account(params = {}) ⇒ Types::DescribeBudgetActionsForAccountResponse
Describes all of the budget actions for an account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1351 1352 1353 1354 |
# File 'lib/aws-sdk-budgets/client.rb', line 1351 def describe_budget_actions_for_account(params = {}, = {}) req = build_request(:describe_budget_actions_for_account, params) req.send_request() end |
#describe_budget_actions_for_budget(params = {}) ⇒ Types::DescribeBudgetActionsForBudgetResponse
Describes all of the budget actions for a budget.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1425 1426 1427 1428 |
# File 'lib/aws-sdk-budgets/client.rb', line 1425 def describe_budget_actions_for_budget(params = {}, = {}) req = build_request(:describe_budget_actions_for_budget, params) req.send_request() end |
#describe_budget_notifications_for_account(params = {}) ⇒ Types::DescribeBudgetNotificationsForAccountResponse
Lists the budget names and notifications that are associated with an account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1472 1473 1474 1475 |
# File 'lib/aws-sdk-budgets/client.rb', line 1472 def describe_budget_notifications_for_account(params = {}, = {}) req = build_request(:describe_budget_notifications_for_account, params) req.send_request() end |
#describe_budget_performance_history(params = {}) ⇒ Types::DescribeBudgetPerformanceHistoryResponse
Describes the history for ‘DAILY`, `MONTHLY`, and `QUARTERLY` budgets. Budget history isn’t available for ‘ANNUAL` budgets.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1575 1576 1577 1578 |
# File 'lib/aws-sdk-budgets/client.rb', line 1575 def describe_budget_performance_history(params = {}, = {}) req = build_request(:describe_budget_performance_history, params) req.send_request() end |
#describe_budgets(params = {}) ⇒ Types::DescribeBudgetsResponse
Lists the budgets that are associated with an account.
The Request Syntax section shows the ‘BudgetLimit` syntax. For `PlannedBudgetLimits`, see the [Examples] section.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1689 1690 1691 1692 |
# File 'lib/aws-sdk-budgets/client.rb', line 1689 def describe_budgets(params = {}, = {}) req = build_request(:describe_budgets, params) req.send_request() end |
#describe_notifications_for_budget(params = {}) ⇒ Types::DescribeNotificationsForBudgetResponse
Lists the notifications that are associated with a budget.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1739 1740 1741 1742 |
# File 'lib/aws-sdk-budgets/client.rb', line 1739 def describe_notifications_for_budget(params = {}, = {}) req = build_request(:describe_notifications_for_budget, params) req.send_request() end |
#describe_subscribers_for_notification(params = {}) ⇒ Types::DescribeSubscribersForNotificationResponse
Lists the subscribers that are associated with a notification.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1796 1797 1798 1799 |
# File 'lib/aws-sdk-budgets/client.rb', line 1796 def describe_subscribers_for_notification(params = {}, = {}) req = build_request(:describe_subscribers_for_notification, params) req.send_request() end |
#execute_budget_action(params = {}) ⇒ Types::ExecuteBudgetActionResponse
Executes a budget action.
1846 1847 1848 1849 |
# File 'lib/aws-sdk-budgets/client.rb', line 1846 def execute_budget_action(params = {}, = {}) req = build_request(:execute_budget_action, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists tags associated with a budget or budget action resource.
1874 1875 1876 1877 |
# File 'lib/aws-sdk-budgets/client.rb', line 1874 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Creates tags for a budget or budget action resource.
1903 1904 1905 1906 |
# File 'lib/aws-sdk-budgets/client.rb', line 1903 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Deletes tags associated with a budget or budget action resource.
1927 1928 1929 1930 |
# File 'lib/aws-sdk-budgets/client.rb', line 1927 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_budget(params = {}) ⇒ Struct
Updates a budget. You can change every part of a budget except for the ‘budgetName` and the `calculatedSpend`. When you modify a budget, the `calculatedSpend` drops to zero until Amazon Web Services has new usage data to use for forecasting.
Only one of ‘BudgetLimit` or `PlannedBudgetLimits` can be present in the syntax at one time. Use the syntax that matches your case. The Request Syntax section shows the `BudgetLimit` syntax. For `PlannedBudgetLimits`, see the [Examples] section.
Similarly, only one set of filter and metric selections can be
present in the syntax at one time. Either ‘FilterExpression` and `Metrics` or `CostFilters` and `CostTypes`, not both or a different combination. We recommend using `FilterExpression` and `Metrics` as they provide more flexible and powerful filtering capabilities. The Request Syntax section shows the `FilterExpression`/`Metrics` syntax.
2062 2063 2064 2065 |
# File 'lib/aws-sdk-budgets/client.rb', line 2062 def update_budget(params = {}, = {}) req = build_request(:update_budget, params) req.send_request() end |
#update_budget_action(params = {}) ⇒ Types::UpdateBudgetActionResponse
Updates a budget action.
2207 2208 2209 2210 |
# File 'lib/aws-sdk-budgets/client.rb', line 2207 def update_budget_action(params = {}, = {}) req = build_request(:update_budget_action, params) req.send_request() end |
#update_notification(params = {}) ⇒ Struct
Updates a notification.
2252 2253 2254 2255 |
# File 'lib/aws-sdk-budgets/client.rb', line 2252 def update_notification(params = {}, = {}) req = build_request(:update_notification, params) req.send_request() end |
#update_subscriber(params = {}) ⇒ Struct
Updates a subscriber.
2301 2302 2303 2304 |
# File 'lib/aws-sdk-budgets/client.rb', line 2301 def update_subscriber(params = {}, = {}) req = build_request(:update_subscriber, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2330 2331 2332 |
# File 'lib/aws-sdk-budgets/client.rb', line 2330 def waiter_names [] end |