Class: Aws::Budgets::Types::BudgetPerformanceHistory
- Inherits:
-
Struct
- Object
- Struct
- Aws::Budgets::Types::BudgetPerformanceHistory
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-budgets/types.rb
Overview
A history of the state of a budget at the end of the budget's specified time period.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#billing_view_arn ⇒ String
The Amazon Resource Name (ARN) that uniquely identifies a specific billing view.
-
#budget_name ⇒ String
A string that represents the budget name.
-
#budget_type ⇒ String
The type of a budget.
-
#budgeted_and_actual_amounts_list ⇒ Array<Types::BudgetedAndActualAmounts>
A list of amounts of cost or usage that you created budgets for, which are compared to your actual costs or usage.
-
#cost_filters ⇒ Hash<String,Array<String>>
The history of the cost filters for a budget during the specified time period.
-
#cost_types ⇒ Types::CostTypes
The history of the cost types for a budget during the specified time period.
-
#filter_expression ⇒ Types::Expression
The filtering dimensions for the budget and their corresponding values.
-
#metrics ⇒ Array<String>
The definition for how the budget data is aggregated.
-
#time_unit ⇒ String
The time unit of the budget, such as MONTHLY or QUARTERLY.
Instance Attribute Details
#billing_view_arn ⇒ String
The Amazon Resource Name (ARN) that uniquely identifies a specific billing view. The ARN is used to specify which particular billing view you want to interact with or retrieve information from when making API calls related to Amazon Web Services Billing and Cost Management features. The BillingViewArn can be retrieved by calling the ListBillingViews API.
453 454 455 456 457 458 459 460 461 462 463 464 465 |
# File 'lib/aws-sdk-budgets/types.rb', line 453 class BudgetPerformanceHistory < Struct.new( :budget_name, :budget_type, :cost_filters, :cost_types, :time_unit, :billing_view_arn, :budgeted_and_actual_amounts_list, :filter_expression, :metrics) SENSITIVE = [] include Aws::Structure end |
#budget_name ⇒ String
A string that represents the budget name. The ":" and "\" characters, and the "/action/" substring, aren't allowed.
Budget names are validated for content. Names that contain phone numbers, URLs, or email addresses combined with certain terms may be rejected.
453 454 455 456 457 458 459 460 461 462 463 464 465 |
# File 'lib/aws-sdk-budgets/types.rb', line 453 class BudgetPerformanceHistory < Struct.new( :budget_name, :budget_type, :cost_filters, :cost_types, :time_unit, :billing_view_arn, :budgeted_and_actual_amounts_list, :filter_expression, :metrics) SENSITIVE = [] include Aws::Structure end |
#budget_type ⇒ String
The type of a budget. It must be one of the following types:
COST, USAGE, RI_UTILIZATION, RI_COVERAGE,
SAVINGS_PLANS_UTILIZATION, or SAVINGS_PLANS_COVERAGE.
453 454 455 456 457 458 459 460 461 462 463 464 465 |
# File 'lib/aws-sdk-budgets/types.rb', line 453 class BudgetPerformanceHistory < Struct.new( :budget_name, :budget_type, :cost_filters, :cost_types, :time_unit, :billing_view_arn, :budgeted_and_actual_amounts_list, :filter_expression, :metrics) SENSITIVE = [] include Aws::Structure end |
#budgeted_and_actual_amounts_list ⇒ Array<Types::BudgetedAndActualAmounts>
A list of amounts of cost or usage that you created budgets for, which are compared to your actual costs or usage.
453 454 455 456 457 458 459 460 461 462 463 464 465 |
# File 'lib/aws-sdk-budgets/types.rb', line 453 class BudgetPerformanceHistory < Struct.new( :budget_name, :budget_type, :cost_filters, :cost_types, :time_unit, :billing_view_arn, :budgeted_and_actual_amounts_list, :filter_expression, :metrics) SENSITIVE = [] include Aws::Structure end |
#cost_filters ⇒ Hash<String,Array<String>>
The history of the cost filters for a budget during the specified time period.
453 454 455 456 457 458 459 460 461 462 463 464 465 |
# File 'lib/aws-sdk-budgets/types.rb', line 453 class BudgetPerformanceHistory < Struct.new( :budget_name, :budget_type, :cost_filters, :cost_types, :time_unit, :billing_view_arn, :budgeted_and_actual_amounts_list, :filter_expression, :metrics) SENSITIVE = [] include Aws::Structure end |
#cost_types ⇒ Types::CostTypes
The history of the cost types for a budget during the specified time period.
453 454 455 456 457 458 459 460 461 462 463 464 465 |
# File 'lib/aws-sdk-budgets/types.rb', line 453 class BudgetPerformanceHistory < Struct.new( :budget_name, :budget_type, :cost_filters, :cost_types, :time_unit, :billing_view_arn, :budgeted_and_actual_amounts_list, :filter_expression, :metrics) SENSITIVE = [] include Aws::Structure end |
#filter_expression ⇒ Types::Expression
The filtering dimensions for the budget and their corresponding values.
453 454 455 456 457 458 459 460 461 462 463 464 465 |
# File 'lib/aws-sdk-budgets/types.rb', line 453 class BudgetPerformanceHistory < Struct.new( :budget_name, :budget_type, :cost_filters, :cost_types, :time_unit, :billing_view_arn, :budgeted_and_actual_amounts_list, :filter_expression, :metrics) SENSITIVE = [] include Aws::Structure end |
#metrics ⇒ Array<String>
The definition for how the budget data is aggregated.
453 454 455 456 457 458 459 460 461 462 463 464 465 |
# File 'lib/aws-sdk-budgets/types.rb', line 453 class BudgetPerformanceHistory < Struct.new( :budget_name, :budget_type, :cost_filters, :cost_types, :time_unit, :billing_view_arn, :budgeted_and_actual_amounts_list, :filter_expression, :metrics) SENSITIVE = [] include Aws::Structure end |
#time_unit ⇒ String
The time unit of the budget, such as MONTHLY or QUARTERLY.
453 454 455 456 457 458 459 460 461 462 463 464 465 |
# File 'lib/aws-sdk-budgets/types.rb', line 453 class BudgetPerformanceHistory < Struct.new( :budget_name, :budget_type, :cost_filters, :cost_types, :time_unit, :billing_view_arn, :budgeted_and_actual_amounts_list, :filter_expression, :metrics) SENSITIVE = [] include Aws::Structure end |