Class: Aws::Budgets::Types::DescribeBudgetActionHistoriesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Budgets::Types::DescribeBudgetActionHistoriesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-budgets/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_id ⇒ String
The account ID of the user.
-
#action_id ⇒ String
A system-generated universally unique identifier (UUID) for the action.
-
#budget_name ⇒ String
A string that represents the budget name.
-
#max_results ⇒ Integer
An integer that represents how many entries a paginated response contains.
-
#next_token ⇒ String
A generic string.
-
#time_period ⇒ Types::TimePeriod
The period of time that’s covered by a budget.
Instance Attribute Details
#account_id ⇒ String
The account ID of the user. It’s a 12-digit number.
1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 |
# File 'lib/aws-sdk-budgets/types.rb', line 1024 class DescribeBudgetActionHistoriesRequest < Struct.new( :account_id, :budget_name, :action_id, :time_period, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#action_id ⇒ String
A system-generated universally unique identifier (UUID) for the action.
1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 |
# File 'lib/aws-sdk-budgets/types.rb', line 1024 class DescribeBudgetActionHistoriesRequest < Struct.new( :account_id, :budget_name, :action_id, :time_period, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#budget_name ⇒ String
A string that represents the budget name. The “:” and “\” characters, and the “/action/” substring, aren’t allowed.
Budget names are validated for content. Names that contain phone numbers, URLs, or email addresses combined with certain terms may be rejected.
1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 |
# File 'lib/aws-sdk-budgets/types.rb', line 1024 class DescribeBudgetActionHistoriesRequest < Struct.new( :account_id, :budget_name, :action_id, :time_period, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
An integer that represents how many entries a paginated response contains. The maximum is 100.
1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 |
# File 'lib/aws-sdk-budgets/types.rb', line 1024 class DescribeBudgetActionHistoriesRequest < Struct.new( :account_id, :budget_name, :action_id, :time_period, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A generic string.
1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 |
# File 'lib/aws-sdk-budgets/types.rb', line 1024 class DescribeBudgetActionHistoriesRequest < Struct.new( :account_id, :budget_name, :action_id, :time_period, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#time_period ⇒ Types::TimePeriod
The period of time that’s covered by a budget. The period has a start date and an end date. The start date must come before the end date. There are no restrictions on the end date.
1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 |
# File 'lib/aws-sdk-budgets/types.rb', line 1024 class DescribeBudgetActionHistoriesRequest < Struct.new( :account_id, :budget_name, :action_id, :time_period, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |